
# Slot: slot_uri


predicate of this slot for semantic web application

URI: [linkml:slot_uri](https://w3id.org/linkml/slot_uri)


## Domain and Range

slot_definition &#8594;  <sub>0..1</sub> uriorcurie

## Parents


## Children


## Used by

 * slot_definition
